@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Hybrid.pm,v 1.9 2005/06/17 18:53:34 fredo Exp $
+#   $Id: Hybrid.pm,v 2.0 2005/11/16 02:18:23 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::XObject::Form::Hybrid;
@@ -50,7 +50,7 @@ BEGIN {
         'PDF::API2::Resource::XObject::Form'
     );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.9 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 18:53:34 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:18:23 $
 }
 no warnings qw[ deprecated recursion uninitialized ];
 
@@ -135,6 +135,18 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Hybrid.pm,v $
+    Revision 2.0  2005/11/16 02:18:23  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.10  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
     Revision 1.9  2005/06/17 18:53:34  fredo
     fixed CPAN modulefile versioning (dislikes cvs)
 
